<?php
/**  ______ _                 _               _ ___
 *  |  ____| |               | |             | |__ \
 *  | |__  | |_   ___      __| |__   ___  ___| |  ) |
 *  |  __| | | | | \ \ /\ / /| '_ \ / _ \/ _ \ | / /
 *  | |    | | |_| |\ V  V / | | | |  __/  __/ |/ /_
 *  |_|    |_|\__, | \_/\_/  |_| |_|\___|\___|_|____|
 *             __/ |
 *            |___/
 *
 * Flywheel2: the inertia php framework
 *
 * @category	Flywheel2
 * @package		other
 * @author		wakaba <wakabadou@gmail.com>
 * @copyright	2011- Wakabadou honpo (http://www.wakabadou.net/) / Project ICKX (http://www.ickx.jp/)
 * @license		http://opensource.org/licenses/MIT The MIT License MIT
 * @varsion		2.0.0
 */

namespace ickx\fw2\other\network;

/**
 * ドメインを纏めて扱うクラスです。
 *
 * @category	Flywheel2
 * @package		other
 * @author		wakaba <wakabadou@gmail.com>
 * @license		http://opensource.org/licenses/MIT The MIT License MIT
 * @varsion		2.0.0
 */
class DomainUtility {
	public const TOP_LEVEL_DOMAIN_LIST	= [
		'com'				=> ['name' => 'com', 'entity' => '商用', 'idn' => true, 'dnssec' => true],
		'org'				=> ['name' => 'org', 'entity' => '団体', 'idn' => true, 'dnssec' => true],
		'net'				=> ['name' => 'net', 'entity' => 'ネットワークインフラ', 'idn' => true, 'dnssec' => true],
		'int'				=> ['name' => 'int', 'entity' => '国際機関', 'idn' => false, 'dnssec' => false],
		'edu'				=> ['name' => 'edu', 'entity' => 'アメリカ合衆国内の高等教育機関', 'idn' => false, 'dnssec' => true],
		'gov'				=> ['name' => 'gov', 'entity' => 'アメリカ合衆国連邦政府', 'idn' => false, 'dnssec' => true],
		'mil'				=> ['name' => 'mil', 'entity' => 'アメリカ合衆国の軍事機関', 'idn' => false, 'dnssec' => true],
		'arpa'				=> ['name' => 'arpa', 'entity' => 'Address and Routing Parameter Area', 'idn' => false, 'dnssec' => true],
		'ac'				=> ['name' => 'ac', 'entity' => 'アセンション島', 'idn' => true, 'dnssec' => true],
		'ad'				=> ['name' => 'ad', 'entity' => 'アンドラ', 'idn' => null, 'dnssec' => true],
		'ae'				=> ['name' => 'ae', 'entity' => 'アラブ首長国連邦', 'idn' => null, 'dnssec' => false],
		'af'				=> ['name' => 'af', 'entity' => 'アフガニスタン', 'idn' => null, 'dnssec' => true],
		'ag'				=> ['name' => 'ag', 'entity' => 'アンティグア・バーブーダ', 'idn' => null, 'dnssec' => true],
		'ai'				=> ['name' => 'ai', 'entity' => 'アンギラ', 'idn' => null, 'dnssec' => false],
		'al'				=> ['name' => 'al', 'entity' => 'アルバニア', 'idn' => null, 'dnssec' => false],
		'am'				=> ['name' => 'am', 'entity' => 'アルメニア', 'idn' => false, 'dnssec' => true],
		'an'				=> ['name' => 'an', 'entity' => 'オランダ領アンティル', 'idn' => null, 'dnssec' => false],
		'ao'				=> ['name' => 'ao', 'entity' => 'アンゴラ', 'idn' => null, 'dnssec' => false],
		'aq'				=> ['name' => 'aq', 'entity' => '南極', 'idn' => null, 'dnssec' => false],
		'ar'				=> ['name' => 'ar', 'entity' => 'アルゼンチン', 'idn' => true, 'dnssec' => true],
		'as'				=> ['name' => 'as', 'entity' => 'アメリカ領サモア', 'idn' => true, 'dnssec' => false],
		'at'				=> ['name' => 'at', 'entity' => 'オーストリア', 'idn' => null, 'dnssec' => true],
		'au'				=> ['name' => 'au', 'entity' => 'オーストラリア', 'idn' => null, 'dnssec' => true],
		'aw'				=> ['name' => 'aw', 'entity' => 'アルバ', 'idn' => null, 'dnssec' => true],
		'ax'				=> ['name' => 'ax', 'entity' => 'オーランド諸島', 'idn' => null, 'dnssec' => false],
		'az'				=> ['name' => 'az', 'entity' => 'アゼルバイジャン', 'idn' => null, 'dnssec' => false],
		'ba'				=> ['name' => 'ba', 'entity' => 'ボスニア・ヘルツェゴビナ', 'idn' => null, 'dnssec' => false],
		'bb'				=> ['name' => 'bb', 'entity' => 'バルバドス', 'idn' => null, 'dnssec' => false],
		'bd'				=> ['name' => 'bd', 'entity' => 'バングラデシュ', 'idn' => true, 'dnssec' => false],
		'be'				=> ['name' => 'be', 'entity' => 'ベルギー', 'idn' => true, 'dnssec' => true],
		'bf'				=> ['name' => 'bf', 'entity' => 'ブルキナファソ', 'idn' => null, 'dnssec' => false],
		'bg'				=> ['name' => 'bg', 'entity' => 'ブルガリア', 'idn' => true, 'dnssec' => true],
		'bh'				=> ['name' => 'bh', 'entity' => 'バーレーン', 'idn' => null, 'dnssec' => false],
		'bi'				=> ['name' => 'bi', 'entity' => 'ブルンジ', 'idn' => null, 'dnssec' => false],
		'bj'				=> ['name' => 'bj', 'entity' => 'ベナン', 'idn' => null, 'dnssec' => false],
		'bm'				=> ['name' => 'bm', 'entity' => 'バミューダ諸島', 'idn' => null, 'dnssec' => false],
		'bn'				=> ['name' => 'bn', 'entity' => 'ブルネイ', 'idn' => null, 'dnssec' => false],
		'bo'				=> ['name' => 'bo', 'entity' => 'ボリビア', 'idn' => null, 'dnssec' => false],
		'bq'				=> ['name' => 'bq', 'entity' => 'ボネール島', 'idn' => null, 'dnssec' => null],
		'br'				=> ['name' => 'br', 'entity' => 'ブラジル', 'idn' => true, 'dnssec' => true],
		'bs'				=> ['name' => 'bs', 'entity' => 'バハマ', 'idn' => null, 'dnssec' => false],
		'bt'				=> ['name' => 'bt', 'entity' => 'ブータン', 'idn' => null, 'dnssec' => false],
		'bv'				=> ['name' => 'bv', 'entity' => 'ブーベ島', 'idn' => false, 'dnssec' => false],
		'bw'				=> ['name' => 'bw', 'entity' => 'ボツワナ', 'idn' => null, 'dnssec' => false],
		'by'				=> ['name' => 'by', 'entity' => 'ベラルーシ', 'idn' => null, 'dnssec' => true],
		'bz'				=> ['name' => 'bz', 'entity' => 'ベリーズ', 'idn' => null, 'dnssec' => true],
		'ca'				=> ['name' => 'ca', 'entity' => 'カナダ', 'idn' => true, 'dnssec' => true],
		'cc'				=> ['name' => 'cc', 'entity' => 'ココス諸島', 'idn' => null, 'dnssec' => true],
		'cd'				=> ['name' => 'cd', 'entity' => 'コンゴ民主共和国', 'idn' => null, 'dnssec' => false],
		'cf'				=> ['name' => 'cf', 'entity' => '中央アフリカ共和国', 'idn' => null, 'dnssec' => false],
		'cg'				=> ['name' => 'cg', 'entity' => 'コンゴ共和国', 'idn' => null, 'dnssec' => false],
		'ch'				=> ['name' => 'ch', 'entity' => 'スイス', 'idn' => true, 'dnssec' => true],
		'ci'				=> ['name' => 'ci', 'entity' => 'コートジボワール', 'idn' => null, 'dnssec' => false],
		'ck'				=> ['name' => 'ck', 'entity' => 'クック諸島', 'idn' => null, 'dnssec' => false],
		'cl'				=> ['name' => 'cl', 'entity' => 'チリ', 'idn' => true, 'dnssec' => true],
		'cm'				=> ['name' => 'cm', 'entity' => 'カメルーン', 'idn' => null, 'dnssec' => false],
		'cn'				=> ['name' => 'cn', 'entity' => '中国', 'idn' => null, 'dnssec' => true],
		'co'				=> ['name' => 'co', 'entity' => 'コロンビア', 'idn' => null, 'dnssec' => true],
		'cr'				=> ['name' => 'cr', 'entity' => 'コスタリカ', 'idn' => null, 'dnssec' => true],
		'cu'				=> ['name' => 'cu', 'entity' => 'キューバ', 'idn' => null, 'dnssec' => false],
		'cv'				=> ['name' => 'cv', 'entity' => 'カーボベルデ', 'idn' => null, 'dnssec' => false],
		'cw'				=> ['name' => 'cw', 'entity' => 'キュラソー島', 'idn' => null, 'dnssec' => false],
		'cx'				=> ['name' => 'cx', 'entity' => 'クリスマス島', 'idn' => null, 'dnssec' => true],
		'cy'				=> ['name' => 'cy', 'entity' => 'キプロス', 'idn' => null, 'dnssec' => false],
		'cz'				=> ['name' => 'cz', 'entity' => 'チェコ', 'idn' => false, 'dnssec' => true],
		'de'				=> ['name' => 'de', 'entity' => 'ドイツ', 'idn' => true, 'dnssec' => true],
		'dj'				=> ['name' => 'dj', 'entity' => 'ジブチ', 'idn' => null, 'dnssec' => false],
		'dk'				=> ['name' => 'dk', 'entity' => 'デンマーク', 'idn' => true, 'dnssec' => true],
		'dm'				=> ['name' => 'dm', 'entity' => 'ドミニカ国', 'idn' => null, 'dnssec' => false],
		'do'				=> ['name' => 'do', 'entity' => 'ドミニカ共和国', 'idn' => null, 'dnssec' => false],
		'dz'				=> ['name' => 'dz', 'entity' => 'アルジェリア', 'idn' => null, 'dnssec' => false],
		'ec'				=> ['name' => 'ec', 'entity' => 'エクアドル', 'idn' => null, 'dnssec' => false],
		'ee'				=> ['name' => 'ee', 'entity' => 'エストニア', 'idn' => true, 'dnssec' => true],
		'eg'				=> ['name' => 'eg', 'entity' => 'エジプト', 'idn' => null, 'dnssec' => false],
		'eh'				=> ['name' => 'eh', 'entity' => '西サハラ', 'idn' => null, 'dnssec' => null],
		'er'				=> ['name' => 'er', 'entity' => 'エリトリア', 'idn' => null, 'dnssec' => false],
		'es'				=> ['name' => 'es', 'entity' => 'スペイン', 'idn' => null, 'dnssec' => true],
		'et'				=> ['name' => 'et', 'entity' => 'エチオピア', 'idn' => null, 'dnssec' => false],
		'eu'				=> ['name' => 'eu', 'entity' => '欧州連合', 'idn' => true, 'dnssec' => true],
		'fi'				=> ['name' => 'fi', 'entity' => 'フィンランド', 'idn' => true, 'dnssec' => true],
		'fj'				=> ['name' => 'fj', 'entity' => 'フィジー', 'idn' => null, 'dnssec' => false],
		'fk'				=> ['name' => 'fk', 'entity' => 'フォークランド諸島', 'idn' => null, 'dnssec' => false],
		'fm'				=> ['name' => 'fm', 'entity' => 'ミクロネシア連邦', 'idn' => null, 'dnssec' => false],
		'fo'				=> ['name' => 'fo', 'entity' => 'フェロー諸島', 'idn' => null, 'dnssec' => true],
		'fr'				=> ['name' => 'fr', 'entity' => 'フランス', 'idn' => true, 'dnssec' => true],
		'ga'				=> ['name' => 'ga', 'entity' => 'ガボン', 'idn' => null, 'dnssec' => false],
		'gb'				=> ['name' => 'gb', 'entity' => 'イギリス', 'idn' => null, 'dnssec' => false],
		'gd'				=> ['name' => 'gd', 'entity' => 'グレナダ', 'idn' => null, 'dnssec' => true],
		'ge'				=> ['name' => 'ge', 'entity' => 'ジョージア', 'idn' => false, 'dnssec' => false],
		'gf'				=> ['name' => 'gf', 'entity' => 'フランス領ギアナ', 'idn' => null, 'dnssec' => false],
		'gg'				=> ['name' => 'gg', 'entity' => 'ガーンジー島', 'idn' => null, 'dnssec' => false],
		'gh'				=> ['name' => 'gh', 'entity' => 'ガーナ', 'idn' => null, 'dnssec' => false],
		'gi'				=> ['name' => 'gi', 'entity' => 'ジブラルタル', 'idn' => null, 'dnssec' => true],
		'gl'				=> ['name' => 'gl', 'entity' => 'グリーンランド', 'idn' => null, 'dnssec' => true],
		'gm'				=> ['name' => 'gm', 'entity' => 'ガンビア', 'idn' => null, 'dnssec' => false],
		'gn'				=> ['name' => 'gn', 'entity' => 'ギニア', 'idn' => null, 'dnssec' => true],
		'gp'				=> ['name' => 'gp', 'entity' => 'グアドループ', 'idn' => null, 'dnssec' => false],
		'gq'				=> ['name' => 'gq', 'entity' => '赤道ギニア', 'idn' => null, 'dnssec' => false],
		'gr'				=> ['name' => 'gr', 'entity' => 'ギリシャ', 'idn' => true, 'dnssec' => true],
		'gs'				=> ['name' => 'gs', 'entity' => 'サウスジョージア・サウスサンドウィッチ諸島', 'idn' => null, 'dnssec' => true],
		'gt'				=> ['name' => 'gt', 'entity' => 'グアテマラ', 'idn' => true, 'dnssec' => false],
		'gu'				=> ['name' => 'gu', 'entity' => 'グアム', 'idn' => null, 'dnssec' => false],
		'gw'				=> ['name' => 'gw', 'entity' => 'ギニアビサウ', 'idn' => null, 'dnssec' => false],
		'gy'				=> ['name' => 'gy', 'entity' => 'ガイアナ', 'idn' => null, 'dnssec' => false],
		'hk'				=> ['name' => 'hk', 'entity' => '香港', 'idn' => true, 'dnssec' => false],
		'hm'				=> ['name' => 'hm', 'entity' => 'ハード島とマクドナルド諸島', 'idn' => null, 'dnssec' => false],
		'hn'				=> ['name' => 'hn', 'entity' => 'ホンジュラス', 'idn' => null, 'dnssec' => true],
		'hr'				=> ['name' => 'hr', 'entity' => 'クロアチア', 'idn' => null, 'dnssec' => true],
		'ht'				=> ['name' => 'ht', 'entity' => 'ハイチ', 'idn' => true, 'dnssec' => false],
		'hu'				=> ['name' => 'hu', 'entity' => 'ハンガリー', 'idn' => null, 'dnssec' => true],
		'id'				=> ['name' => 'id', 'entity' => 'インドネシア', 'idn' => true, 'dnssec' => true],
		'ie'				=> ['name' => 'ie', 'entity' => 'アイルランド', 'idn' => false, 'dnssec' => true],
		'il'				=> ['name' => 'il', 'entity' => 'イスラエル', 'idn' => true, 'dnssec' => false],
		'im'				=> ['name' => 'im', 'entity' => 'マン島', 'idn' => null, 'dnssec' => false],
		'in'				=> ['name' => 'in', 'entity' => 'インド', 'idn' => null, 'dnssec' => true],
		'io'				=> ['name' => 'io', 'entity' => 'イギリス領インド洋地域', 'idn' => null, 'dnssec' => true],
		'iq'				=> ['name' => 'iq', 'entity' => 'イラク', 'idn' => null, 'dnssec' => true],
		'ir'				=> ['name' => 'ir', 'entity' => 'イラン', 'idn' => true, 'dnssec' => false],
		'is'				=> ['name' => 'is', 'entity' => 'アイスランド', 'idn' => true, 'dnssec' => true],
		'it'				=> ['name' => 'it', 'entity' => 'イタリア', 'idn' => true, 'dnssec' => false],
		'je'				=> ['name' => 'je', 'entity' => 'ジャージー島', 'idn' => null, 'dnssec' => false],
		'jm'				=> ['name' => 'jm', 'entity' => 'ジャマイカ', 'idn' => null, 'dnssec' => false],
		'jo'				=> ['name' => 'jo', 'entity' => 'ヨルダン', 'idn' => null, 'dnssec' => false],
		'jp'				=> ['name' => 'jp', 'entity' => '日本', 'idn' => null, 'dnssec' => true],
		'ke'				=> ['name' => 'ke', 'entity' => 'ケニア', 'idn' => null, 'dnssec' => true],
		'kg'				=> ['name' => 'kg', 'entity' => 'キルギス', 'idn' => null, 'dnssec' => true],
		'kh'				=> ['name' => 'kh', 'entity' => 'カンボジア', 'idn' => null, 'dnssec' => false],
		'ki'				=> ['name' => 'ki', 'entity' => 'キリバス', 'idn' => null, 'dnssec' => true],
		'km'				=> ['name' => 'km', 'entity' => 'コモロ', 'idn' => null, 'dnssec' => false],
		'kn'				=> ['name' => 'kn', 'entity' => 'セントクリストファー・ネイビス', 'idn' => null, 'dnssec' => false],
		'kp'				=> ['name' => 'kp', 'entity' => '朝鮮民主主義人民共和国', 'idn' => null, 'dnssec' => false],
		'kr'				=> ['name' => 'kr', 'entity' => '韓国', 'idn' => true, 'dnssec' => true],
		'krd'				=> ['name' => 'krd', 'entity' => 'クルディスタン地域', 'idn' => null, 'dnssec' => true],
		'kw'				=> ['name' => 'kw', 'entity' => 'クウェート', 'idn' => null, 'dnssec' => false],
		'ky'				=> ['name' => 'ky', 'entity' => 'ケイマン諸島', 'idn' => null, 'dnssec' => true],
		'kz'				=> ['name' => 'kz', 'entity' => 'カザフスタン', 'idn' => null, 'dnssec' => false],
		'la'				=> ['name' => 'la', 'entity' => 'ラオス', 'idn' => null, 'dnssec' => true],
		'lb'				=> ['name' => 'lb', 'entity' => 'レバノン', 'idn' => null, 'dnssec' => true],
		'lc'				=> ['name' => 'lc', 'entity' => 'セントルシア', 'idn' => null, 'dnssec' => true],
		'li'				=> ['name' => 'li', 'entity' => 'リヒテンシュタイン', 'idn' => true, 'dnssec' => true],
		'lk'				=> ['name' => 'lk', 'entity' => 'スリランカ', 'idn' => null, 'dnssec' => true],
		'lr'				=> ['name' => 'lr', 'entity' => 'リベリア', 'idn' => null, 'dnssec' => true],
		'ls'				=> ['name' => 'ls', 'entity' => 'レソト', 'idn' => null, 'dnssec' => false],
		'lt'				=> ['name' => 'lt', 'entity' => 'リトアニア', 'idn' => true, 'dnssec' => true],
		'lu'				=> ['name' => 'lu', 'entity' => 'ルクセンブルク', 'idn' => true, 'dnssec' => true],
		'lv'				=> ['name' => 'lv', 'entity' => 'ラトビア', 'idn' => true, 'dnssec' => true],
		'ly'				=> ['name' => 'ly', 'entity' => 'リビア', 'idn' => null, 'dnssec' => false],
		'ma'				=> ['name' => 'ma', 'entity' => 'モロッコ', 'idn' => null, 'dnssec' => true],
		'mc'				=> ['name' => 'mc', 'entity' => 'モナコ', 'idn' => null, 'dnssec' => false],
		'md'				=> ['name' => 'md', 'entity' => 'モルドバ', 'idn' => null, 'dnssec' => false],
		'me'				=> ['name' => 'me', 'entity' => 'モンテネグロ', 'idn' => null, 'dnssec' => true],
		'mg'				=> ['name' => 'mg', 'entity' => 'マダガスカル', 'idn' => null, 'dnssec' => false],
		'mh'				=> ['name' => 'mh', 'entity' => 'マーシャル諸島', 'idn' => null, 'dnssec' => false],
		'mk'				=> ['name' => 'mk', 'entity' => 'マケドニア共和国', 'idn' => null, 'dnssec' => false],
		'ml'				=> ['name' => 'ml', 'entity' => 'マリ', 'idn' => null, 'dnssec' => false],
		'mm'				=> ['name' => 'mm', 'entity' => 'ミャンマー', 'idn' => null, 'dnssec' => true],
		'mn'				=> ['name' => 'mn', 'entity' => 'モンゴル', 'idn' => null, 'dnssec' => true],
		'mo'				=> ['name' => 'mo', 'entity' => 'マカオ', 'idn' => null, 'dnssec' => false],
		'mp'				=> ['name' => 'mp', 'entity' => '北マリアナ諸島', 'idn' => null, 'dnssec' => false],
		'mq'				=> ['name' => 'mq', 'entity' => 'マルティニーク', 'idn' => null, 'dnssec' => false],
		'mr'				=> ['name' => 'mr', 'entity' => 'モーリタニア', 'idn' => null, 'dnssec' => false],
		'ms'				=> ['name' => 'ms', 'entity' => 'モントセラト', 'idn' => null, 'dnssec' => false],
		'mt'				=> ['name' => 'mt', 'entity' => 'マルタ', 'idn' => null, 'dnssec' => false],
		'mu'				=> ['name' => 'mu', 'entity' => 'モーリシャス', 'idn' => null, 'dnssec' => false],
		'mv'				=> ['name' => 'mv', 'entity' => 'モルディブ', 'idn' => null, 'dnssec' => false],
		'mw'				=> ['name' => 'mw', 'entity' => 'マラウイ', 'idn' => null, 'dnssec' => false],
		'mx'				=> ['name' => 'mx', 'entity' => 'メキシコ', 'idn' => null, 'dnssec' => true],
		'my'				=> ['name' => 'my', 'entity' => 'マレーシア', 'idn' => true, 'dnssec' => true],
		'mz'				=> ['name' => 'mz', 'entity' => 'モザンビーク', 'idn' => null, 'dnssec' => false],
		'na'				=> ['name' => 'na', 'entity' => 'ナミビア', 'idn' => null, 'dnssec' => true],
		'nc'				=> ['name' => 'nc', 'entity' => 'ニューカレドニア', 'idn' => null, 'dnssec' => true],
		'ne'				=> ['name' => 'ne', 'entity' => 'ニジェール', 'idn' => null, 'dnssec' => false],
		'nf'				=> ['name' => 'nf', 'entity' => 'ノーフォーク島', 'idn' => null, 'dnssec' => true],
		'ng'				=> ['name' => 'ng', 'entity' => 'ナイジェリア', 'idn' => null, 'dnssec' => false],
		'ni'				=> ['name' => 'ni', 'entity' => 'ニカラグア', 'idn' => null, 'dnssec' => false],
		'nl'				=> ['name' => 'nl', 'entity' => 'オランダ', 'idn' => false, 'dnssec' => true],
		'no'				=> ['name' => 'no', 'entity' => 'ノルウェー', 'idn' => true, 'dnssec' => true],
		'np'				=> ['name' => 'np', 'entity' => 'ネパール', 'idn' => null, 'dnssec' => false],
		'nr'				=> ['name' => 'nr', 'entity' => 'ナウル', 'idn' => null, 'dnssec' => false],
		'nu'				=> ['name' => 'nu', 'entity' => 'ニウエ', 'idn' => true, 'dnssec' => true],
		'nz'				=> ['name' => 'nz', 'entity' => 'ニュージーランド', 'idn' => true, 'dnssec' => true],
		'om'				=> ['name' => 'om', 'entity' => 'オマーン', 'idn' => null, 'dnssec' => false],
		'pa'				=> ['name' => 'pa', 'entity' => 'パナマ', 'idn' => null, 'dnssec' => false],
		'pe'				=> ['name' => 'pe', 'entity' => 'ペルー', 'idn' => true, 'dnssec' => true],
		'pf'				=> ['name' => 'pf', 'entity' => 'フランス領ポリネシア', 'idn' => null, 'dnssec' => false],
		'pg'				=> ['name' => 'pg', 'entity' => 'パプアニューギニア', 'idn' => null, 'dnssec' => false],
		'ph'				=> ['name' => 'ph', 'entity' => 'フィリピン', 'idn' => null, 'dnssec' => false],
		'pk'				=> ['name' => 'pk', 'entity' => 'パキスタン', 'idn' => null, 'dnssec' => false],
		'pl'				=> ['name' => 'pl', 'entity' => 'ポーランド', 'idn' => true, 'dnssec' => true],
		'pm'				=> ['name' => 'pm', 'entity' => 'サンピエール島・ミクロン島', 'idn' => true, 'dnssec' => true],
		'pn'				=> ['name' => 'pn', 'entity' => 'ピトケアン諸島', 'idn' => null, 'dnssec' => false],
		'pr'				=> ['name' => 'pr', 'entity' => 'プエルトリコ', 'idn' => null, 'dnssec' => true],
		'ps'				=> ['name' => 'ps', 'entity' => 'パレスチナ', 'idn' => null, 'dnssec' => false],
		'pt'				=> ['name' => 'pt', 'entity' => 'ポルトガル', 'idn' => true, 'dnssec' => true],
		'pw'				=> ['name' => 'pw', 'entity' => 'パラオ', 'idn' => null, 'dnssec' => true],
		'py'				=> ['name' => 'py', 'entity' => 'パラグアイ', 'idn' => null, 'dnssec' => false],
		'qa'				=> ['name' => 'qa', 'entity' => 'カタール', 'idn' => null, 'dnssec' => false],
		're'				=> ['name' => 're', 'entity' => 'レユニオン', 'idn' => true, 'dnssec' => true],
		'ro'				=> ['name' => 'ro', 'entity' => 'ルーマニア', 'idn' => null, 'dnssec' => false],
		'rs'				=> ['name' => 'rs', 'entity' => 'セルビア', 'idn' => null, 'dnssec' => false],
		'ru'				=> ['name' => 'ru', 'entity' => 'ロシア', 'idn' => false, 'dnssec' => true],
		'rw'				=> ['name' => 'rw', 'entity' => 'ルワンダ', 'idn' => null, 'dnssec' => false],
		'sa'				=> ['name' => 'sa', 'entity' => 'サウジアラビア', 'idn' => true, 'dnssec' => false],
		'sb'				=> ['name' => 'sb', 'entity' => 'ソロモン諸島', 'idn' => null, 'dnssec' => true],
		'sc'				=> ['name' => 'sc', 'entity' => 'セーシェル', 'idn' => null, 'dnssec' => true],
		'sd'				=> ['name' => 'sd', 'entity' => 'スーダン', 'idn' => null, 'dnssec' => false],
		'se'				=> ['name' => 'se', 'entity' => 'スウェーデン', 'idn' => true, 'dnssec' => true],
		'sg'				=> ['name' => 'sg', 'entity' => 'シンガポール', 'idn' => null, 'dnssec' => false],
		'sh'				=> ['name' => 'sh', 'entity' => 'セントヘレナ', 'idn' => true, 'dnssec' => true],
		'si'				=> ['name' => 'si', 'entity' => 'スロベニア', 'idn' => true, 'dnssec' => true],
		'sj'				=> ['name' => 'sj', 'entity' => 'スヴァールバル諸島・', 'idn' => false, 'dnssec' => true],
		'sk'				=> ['name' => 'sk', 'entity' => 'ヤンマイエン島', 'idn' => null, 'dnssec' => false],
		'sl'				=> ['name' => 'sl', 'entity' => 'スロバキア', 'idn' => null, 'dnssec' => false],
		'sm'				=> ['name' => 'sm', 'entity' => 'シエラレオネ', 'idn' => null, 'dnssec' => false],
		'sn'				=> ['name' => 'sn', 'entity' => 'サンマリノ', 'idn' => null, 'dnssec' => false],
		'so'				=> ['name' => 'so', 'entity' => 'セネガル', 'idn' => false, 'dnssec' => false],
		'sr'				=> ['name' => 'sr', 'entity' => 'ソマリア', 'idn' => null, 'dnssec' => false],
		'ss'				=> ['name' => 'ss', 'entity' => 'スリナム', 'idn' => null, 'dnssec' => null],
		'st'				=> ['name' => 'st', 'entity' => '南スーダン', 'idn' => null, 'dnssec' => false],
		'su'				=> ['name' => 'su', 'entity' => 'サントメ・プリンシペ', 'idn' => true, 'dnssec' => true],
		'sv'				=> ['name' => 'sv', 'entity' => 'ソビエト連邦', 'idn' => null, 'dnssec' => false],
		'sx'				=> ['name' => 'sx', 'entity' => 'エルサルバドル', 'idn' => null, 'dnssec' => true],
		'sy'				=> ['name' => 'sy', 'entity' => 'シント・マールテン', 'idn' => null, 'dnssec' => false],
		'sz'				=> ['name' => 'sz', 'entity' => 'シリア', 'idn' => null, 'dnssec' => false],
		'tc'				=> ['name' => 'tc', 'entity' => 'スワジランド', 'idn' => null, 'dnssec' => false],
		'td'				=> ['name' => 'td', 'entity' => 'タークス・カイコス諸島', 'idn' => null, 'dnssec' => false],
		'tf'				=> ['name' => 'tf', 'entity' => 'チャド', 'idn' => true, 'dnssec' => true],
		'tg'				=> ['name' => 'tg', 'entity' => 'フランス領南方・南極地域', 'idn' => null, 'dnssec' => false],
		'th'				=> ['name' => 'th', 'entity' => 'トーゴ', 'idn' => true, 'dnssec' => true],
		'tj'				=> ['name' => 'tj', 'entity' => 'タイ', 'idn' => null, 'dnssec' => false],
		'tk'				=> ['name' => 'tk', 'entity' => 'タジキスタン', 'idn' => null, 'dnssec' => false],
		'tl'				=> ['name' => 'tl', 'entity' => 'トケラウ', 'idn' => null, 'dnssec' => false],
		'tm'				=> ['name' => 'tm', 'entity' => '東ティモール', 'idn' => true, 'dnssec' => true],
		'tn'				=> ['name' => 'tn', 'entity' => 'トルクメニスタン', 'idn' => null, 'dnssec' => true],
		'to'				=> ['name' => 'to', 'entity' => 'チュニジア', 'idn' => true, 'dnssec' => false],
		'tp'				=> ['name' => 'tp', 'entity' => 'トンガ', 'idn' => null, 'dnssec' => false],
		'tr'				=> ['name' => 'tr', 'entity' => '東ティモール', 'idn' => true, 'dnssec' => false],
		'tt'				=> ['name' => 'tt', 'entity' => 'トルコ', 'idn' => null, 'dnssec' => true],
		'tv'				=> ['name' => 'tv', 'entity' => 'トリニダード・トバゴ', 'idn' => null, 'dnssec' => true],
		'tw'				=> ['name' => 'tw', 'entity' => 'ツバル', 'idn' => true, 'dnssec' => true],
		'tz'				=> ['name' => 'tz', 'entity' => '台湾', 'idn' => null, 'dnssec' => true],
		'ua'				=> ['name' => 'ua', 'entity' => 'タンザニア', 'idn' => null, 'dnssec' => true],
		'ug'				=> ['name' => 'ug', 'entity' => 'ウクライナ', 'idn' => null, 'dnssec' => true],
		'uk'				=> ['name' => 'uk', 'entity' => 'ウガンダ', 'idn' => null, 'dnssec' => true],
		'us'				=> ['name' => 'us', 'entity' => 'イギリス', 'idn' => null, 'dnssec' => true],
		'uy'				=> ['name' => 'uy', 'entity' => 'アメリカ', 'idn' => null, 'dnssec' => true],
		'uz'				=> ['name' => 'uz', 'entity' => 'ウルグアイ', 'idn' => null, 'dnssec' => false],
		'va'				=> ['name' => 'va', 'entity' => 'ウズベキスタン', 'idn' => null, 'dnssec' => false],
		'vc'				=> ['name' => 'vc', 'entity' => 'バチカン市国', 'idn' => null, 'dnssec' => true],
		've'				=> ['name' => 've', 'entity' => 'セントビンセント・グレナディーン', 'idn' => null, 'dnssec' => false],
		'vg'				=> ['name' => 'vg', 'entity' => 'ベネズエラ', 'idn' => null, 'dnssec' => false],
		'vi'				=> ['name' => 'vi', 'entity' => 'イギリス領ヴァージン諸島', 'idn' => null, 'dnssec' => false],
		'vn'				=> ['name' => 'vn', 'entity' => 'アメリカ領ヴァージン諸島', 'idn' => true, 'dnssec' => false],
		'vu'				=> ['name' => 'vu', 'entity' => 'ベトナム', 'idn' => null, 'dnssec' => true],
		'wf'				=> ['name' => 'wf', 'entity' => 'バヌアツ', 'idn' => true, 'dnssec' => true],
		'ws'				=> ['name' => 'ws', 'entity' => 'ウォリス・フツナ', 'idn' => true, 'dnssec' => true],
		'ye'				=> ['name' => 'ye', 'entity' => 'サモア', 'idn' => null, 'dnssec' => false],
		'yt'				=> ['name' => 'yt', 'entity' => 'イエメン', 'idn' => true, 'dnssec' => true],
		'za'				=> ['name' => 'za', 'entity' => 'マヨット島', 'idn' => null, 'dnssec' => false],
		'zm'				=> ['name' => 'zm', 'entity' => '南アフリカ', 'idn' => null, 'dnssec' => true],
		'zw'				=> ['name' => 'zw', 'entity' => 'ザンビア', 'idn' => null, 'dnssec' => false],
		'academy'			=> ['name' => 'academy', 'entity' => 'ジンバブエ', 'idn' => true, 'dnssec' => false],
		'الجزائر'				=> ['name' => 'الجزائر', 'entity' => 'アルジェリア', 'idn' => true, 'dnssec' => false],
		'հայ'				=> ['name' => 'հայ', 'entity' => 'アルメニア', 'idn' => true, 'dnssec' => true],
		'বাংলা'				=> ['name' => 'বাংলা', 'entity' => 'バングラデシュ', 'idn' => true, 'dnssec' => false],
		'бел'				=> ['name' => 'бел', 'entity' => 'ベラルーシ', 'idn' => true, 'dnssec' => false],
		'бг'				=> ['name' => 'бг', 'entity' => 'ブルガリア', 'idn' => true, 'dnssec' => false],
		'中国'				=> ['name' => '中国', 'entity' => '中国', 'idn' => true, 'dnssec' => true],
		'中國'				=> ['name' => '中國', 'entity' => '中国', 'idn' => true, 'dnssec' => true],
		'مصر'				=> ['name' => 'مصر', 'entity' => 'エジプト', 'idn' => true, 'dnssec' => true],
		'ею'				=> ['name' => 'ею', 'entity' => '欧州連合', 'idn' => true, 'dnssec' => false],
		'გე'					=> ['name' => 'გე', 'entity' => 'ジョージア', 'idn' => true, 'dnssec' => false],
		'ελ'				=> ['name' => 'ελ', 'entity' => 'ギリシャ', 'idn' => true, 'dnssec' => false],
		'香港'				=> ['name' => '香港', 'entity' => '香港', 'idn' => true, 'dnssec' => false],
		'भारत'				=> ['name' => 'भारत', 'entity' => 'インド', 'idn' => true, 'dnssec' => true],
		'بھارت'				=> ['name' => 'بھارت', 'entity' => 'インド', 'idn' => true, 'dnssec' => true],
		'భారత్'				=> ['name' => 'భారత్', 'entity' => 'インド', 'idn' => true, 'dnssec' => true],
		'ભારત'				=> ['name' => 'ભારત', 'entity' => 'インド', 'idn' => true, 'dnssec' => true],
		'ਭਾਰਤ'				=> ['name' => 'ਭਾਰਤ', 'entity' => 'インド', 'idn' => true, 'dnssec' => true],
		'இந்தியா'			=> ['name' => 'இந்தியா', 'entity' => 'インド', 'idn' => true, 'dnssec' => true],
		'ভারত'				=> ['name' => 'ভারত', 'entity' => 'インド', 'idn' => true, 'dnssec' => true],
		'ایران'				=> ['name' => 'ایران', 'entity' => 'イラン', 'idn' => true, 'dnssec' => false],
		'عراق'				=> ['name' => 'عراق', 'entity' => 'イラク', 'idn' => true, 'dnssec' => false],
		'الاردن'				=> ['name' => 'الاردن', 'entity' => 'ヨルダン', 'idn' => true, 'dnssec' => false],
		'қаз'				=> ['name' => 'қаз', 'entity' => 'カザフスタン', 'idn' => true, 'dnssec' => false],
		'澳门'				=> ['name' => '澳门', 'entity' => 'マカオ', 'idn' => true, 'dnssec' => false],
		'澳門'				=> ['name' => '澳門', 'entity' => 'マカオ', 'idn' => true, 'dnssec' => false],
		'мкд'				=> ['name' => 'мкд', 'entity' => 'マケドニア共和国', 'idn' => true, 'dnssec' => false],
		'مليسيا'				=> ['name' => 'مليسيا', 'entity' => 'マレーシア', 'idn' => true, 'dnssec' => true],
		'мон'				=> ['name' => 'мон', 'entity' => 'モンゴル', 'idn' => true, 'dnssec' => true],
		'المغرب'				=> ['name' => 'المغرب', 'entity' => 'モロッコ', 'idn' => true, 'dnssec' => false],
		'عمان'				=> ['name' => 'عمان', 'entity' => 'オマーン', 'idn' => true, 'dnssec' => false],
		'پاکستان'				=> ['name' => 'پاکستان', 'entity' => 'パキスタン', 'idn' => true, 'dnssec' => false],
		'فلسطين'				=> ['name' => 'فلسطين', 'entity' => 'パレスチナ', 'idn' => true, 'dnssec' => false],
		'قطر'					=> ['name' => 'قطر', 'entity' => 'カタール', 'idn' => true, 'dnssec' => false],
		'рф'				=> ['name' => 'рф', 'entity' => 'ロシア', 'idn' => true, 'dnssec' => true],
		'السعودية'				=> ['name' => 'السعودية', 'entity' => 'サウジアラビア', 'idn' => true, 'dnssec' => false],
		'срб'				=> ['name' => 'срб', 'entity' => 'セルビア', 'idn' => true, 'dnssec' => false],
		'新加坡'				=> ['name' => '新加坡', 'entity' => 'シンガポール', 'idn' => true, 'dnssec' => false],
		'சிங்கப்ப ூர்'			=> ['name' => 'சிங்கப்பூர்', 'entity' => 'シンガポール', 'idn' => true, 'dnssec' => false],
		'한국'				=> ['name' => '한국', 'entity' => '韓国', 'idn' => true, 'dnssec' => true],
		'ලංකා'				=> ['name' => 'ලංකා', 'entity' => 'スリランカ', 'idn' => true, 'dnssec' => true],
		'இலங்கை'			=> ['name' => 'இலங்கை', 'entity' => 'スリランカ', 'idn' => true, 'dnssec' => true],
		'سودان'				=> ['name' => 'سودان', 'entity' => 'スーダン', 'idn' => true, 'dnssec' => false],
		'سورية'				=> ['name' => 'سورية', 'entity' => 'シリア', 'idn' => true, 'dnssec' => false],
		'台湾'				=> ['name' => '台湾', 'entity' => '台湾', 'idn' => true, 'dnssec' => true],
		'台灣'				=> ['name' => '台灣', 'entity' => '台湾', 'idn' => true, 'dnssec' => true],
		'ไทย'				=> ['name' => 'ไทย', 'entity' => 'タイ', 'idn' => true, 'dnssec' => true],
		'تونس'				=> ['name' => 'تونس', 'entity' => 'チュニジア', 'idn' => true, 'dnssec' => true],
		'укр'				=> ['name' => 'укр', 'entity' => 'ウクライナ', 'idn' => true, 'dnssec' => false],
		'امارات'				=> ['name' => 'امارات', 'entity' => 'アラブ首長国連邦', 'idn' => true, 'dnssec' => false],
		'اليمن'				=> ['name' => 'اليمن', 'entity' => 'イエメン', 'idn' => true, 'dnssec' => false],
		'academy'			=> ['name' => 'academy', 'entity' => 'academic institutes', 'idn' => true, 'dnssec' => true],
		'accountant'		=> ['name' => 'accountant', 'entity' => 'accountants and accounting firms', 'idn' => null, 'dnssec' => true],
		'accountants'		=> ['name' => 'accountants', 'entity' => 'accountants and accounting firms', 'idn' => true, 'dnssec' => true],
		'active'			=> ['name' => 'active', 'entity' => 'general', 'idn' => null, 'dnssec' => true],
		'actor'				=> ['name' => 'actor', 'entity' => 'actors', 'idn' => true, 'dnssec' => true],
		'adult'				=> ['name' => 'adult', 'entity' => 'adult entertainment (pornography)', 'idn' => true, 'dnssec' => true],
		'aero'				=> ['name' => 'aero', 'entity' => '航空業界', 'idn' => false, 'dnssec' => false],
		'agency'			=> ['name' => 'agency', 'entity' => 'business associations', 'idn' => true, 'dnssec' => true],
		'airforce'			=> ['name' => 'airforce', 'entity' => 'defense contractors', 'idn' => null, 'dnssec' => true],
		'apartments'		=> ['name' => 'apartments', 'entity' => 'apartments', 'idn' => true, 'dnssec' => true],
		'app'				=> ['name' => 'app', 'entity' => 'Phone apps', 'idn' => null, 'dnssec' => true],
		'archi'				=> ['name' => 'archi', 'entity' => 'architects and architect firms', 'idn' => null, 'dnssec' => true],
		'army'				=> ['name' => 'army', 'entity' => 'defense contractors', 'idn' => null, 'dnssec' => true],
		'associates'		=> ['name' => 'associates', 'entity' => 'business associations', 'idn' => true, 'dnssec' => true],
		'attorney'			=> ['name' => 'attorney', 'entity' => 'attorneys and legal organizations', 'idn' => null, 'dnssec' => true],
		'auction'			=> ['name' => 'auction', 'entity' => 'auction', 'idn' => null, 'dnssec' => true],
		'audio'				=> ['name' => 'audio', 'entity' => 'stereo/sound systems, music', 'idn' => true, 'dnssec' => true],
		'autos'				=> ['name' => 'autos', 'entity' => 'autos', 'idn' => null, 'dnssec' => true],
		'band'				=> ['name' => 'band', 'entity' => 'band', 'idn' => null, 'dnssec' => true],
		'bar'				=> ['name' => 'bar', 'entity' => 'Bars and related industry', 'idn' => true, 'dnssec' => true],
		'bargains'			=> ['name' => 'bargains', 'entity' => 'coupons and online sellers', 'idn' => true, 'dnssec' => true],
		'beer'				=> ['name' => 'beer', 'entity' => 'breweries and beer aficionados', 'idn' => null, 'dnssec' => true],
		'best'				=> ['name' => 'best', 'entity' => 'best', 'idn' => null, 'dnssec' => true],
		'bid'				=> ['name' => 'bid', 'entity' => 'auctions', 'idn' => true, 'dnssec' => true],
		'bike'				=> ['name' => 'bike', 'entity' => 'bicycles', 'idn' => true, 'dnssec' => true],
		'bingo'				=> ['name' => 'bingo', 'entity' => 'ビンゴ', 'idn' => true, 'dnssec' => true],
		'bio'				=> ['name' => 'bio', 'entity' => 'biodiversity, biographies', 'idn' => null, 'dnssec' => true],
		'biz'				=> ['name' => 'biz', 'entity' => 'ビジネス', 'idn' => true, 'dnssec' => true],
		'black'				=> ['name' => 'black', 'entity' => 'those who like the color black', 'idn' => true, 'dnssec' => true],
		'blackfriday'		=> ['name' => 'blackfriday', 'entity' => 'ブラックフライデー', 'idn' => true, 'dnssec' => true],
		'blog'				=> ['name' => 'blog', 'entity' => 'Blogs', 'idn' => null, 'dnssec' => true],
		'blue'				=> ['name' => 'blue', 'entity' => 'those who like the color blue', 'idn' => true, 'dnssec' => true],
		'boo'				=> ['name' => 'boo', 'entity' => 'ghosts and spooky business', 'idn' => null, 'dnssec' => true],
		'boutique'			=> ['name' => 'boutique', 'entity' => 'specialized businesses', 'idn' => true, 'dnssec' => true],
		'build'				=> ['name' => 'build', 'entity' => 'construction industry', 'idn' => true, 'dnssec' => true],
		'builders'			=> ['name' => 'builders', 'entity' => 'construction workers', 'idn' => true, 'dnssec' => true],
		'business'			=> ['name' => 'business', 'entity' => 'businesses', 'idn' => true, 'dnssec' => true],
		'buzz'				=> ['name' => 'buzz', 'entity' => 'marketing and social networking', 'idn' => true, 'dnssec' => true],
		'cab'				=> ['name' => 'cab', 'entity' => 'cabs and taxi companies', 'idn' => true, 'dnssec' => true],
		'camera'			=> ['name' => 'camera', 'entity' => 'camera-related businesses', 'idn' => true, 'dnssec' => true],
		'camp'				=> ['name' => 'camp', 'entity' => 'camps and camping', 'idn' => true, 'dnssec' => true],
		'cancerresearch'	=> ['name' => 'cancerresearch', 'entity' => 'Organizations, research institutes and individuals interested in ending cancer through research ', 'idn' => null, 'dnssec' => TRUE],
		'capital'			=> ['name' => 'capital', 'entity' => 'financial firms', 'idn' => true, 'dnssec' => true],
		'cards'				=> ['name' => 'cards', 'entity' => 'general', 'idn' => true, 'dnssec' => true],
		'care'				=> ['name' => 'care', 'entity' => 'healthcare industry', 'idn' => true, 'dnssec' => true],
		'career'			=> ['name' => 'career', 'entity' => 'career', 'idn' => true, 'dnssec' => true],
		'careers'			=> ['name' => 'careers', 'entity' => 'Employment', 'idn' => true, 'dnssec' => true],
		'cash'				=> ['name' => 'cash', 'entity' => 'financial', 'idn' => true, 'dnssec' => true],
		'casino'			=> ['name' => 'casino', 'entity' => 'カジノ', 'idn' => true, 'dnssec' => true],
		'catering'			=> ['name' => 'catering', 'entity' => 'Food service', 'idn' => true, 'dnssec' => true],
		'center'			=> ['name' => 'center', 'entity' => 'general', 'idn' => true, 'dnssec' => true],
		'ceo'				=> ['name' => 'ceo', 'entity' => 'CEOs', 'idn' => null, 'dnssec' => true],
		'channel'			=> ['name' => 'channel', 'entity' => 'channel', 'idn' => null, 'dnssec' => true],
		'chat'				=> ['name' => 'chat', 'entity' => 'online chat', 'idn' => true, 'dnssec' => true],
		'cheap'				=> ['name' => 'cheap', 'entity' => 'Resellers', 'idn' => true, 'dnssec' => true],
		'christmas'			=> ['name' => 'christmas', 'entity' => 'Christmas', 'idn' => true, 'dnssec' => true],
		'church'			=> ['name' => 'church', 'entity' => 'churches', 'idn' => true, 'dnssec' => true],
		'city'				=> ['name' => 'city', 'entity' => 'general', 'idn' => true, 'dnssec' => true],
		'claims'			=> ['name' => 'claims', 'entity' => 'retail, auctions', 'idn' => true, 'dnssec' => true],
		'cleaning'			=> ['name' => 'cleaning', 'entity' => 'Cleaning services', 'idn' => true, 'dnssec' => true],
		'click'				=> ['name' => 'click', 'entity' => 'click', 'idn' => true, 'dnssec' => true],
		'clinic'			=> ['name' => 'clinic', 'entity' => 'healthcare clinics', 'idn' => true, 'dnssec' => true],
		'clothing'			=> ['name' => 'clothing', 'entity' => 'Apparel', 'idn' => true, 'dnssec' => true],
		'club'				=> ['name' => 'club', 'entity' => 'groups, organizations, assemblies, communities, general', 'idn' => true, 'dnssec' => true],
		'coach'				=> ['name' => 'coach', 'entity' => 'travel (flights and motor coaches)', 'idn' => true, 'dnssec' => true],
		'codes'				=> ['name' => 'codes', 'entity' => 'computer and/or encryption code enthusiasts', 'idn' => true, 'dnssec' => true],
		'coffee'			=> ['name' => 'coffee', 'entity' => 'cafés and coffee aficionados', 'idn' => true, 'dnssec' => true],
		'college'			=> ['name' => 'college', 'entity' => 'Educational', 'idn' => true, 'dnssec' => true],
		'community'			=> ['name' => 'community', 'entity' => 'social groups, neighborhoods', 'idn' => true, 'dnssec' => true],
		'company'			=> ['name' => 'company', 'entity' => 'business associations', 'idn' => true, 'dnssec' => true],
		'computer'			=> ['name' => 'computer', 'entity' => 'Technology', 'idn' => true, 'dnssec' => true],
		'condos'			=> ['name' => 'condos', 'entity' => 'Real estate', 'idn' => true, 'dnssec' => true],
		'construction'		=> ['name' => 'construction', 'entity' => 'Construction industry', 'idn' => true, 'dnssec' => true],
		'consulting'		=> ['name' => 'consulting', 'entity' => 'hired advisors', 'idn' => true, 'dnssec' => true],
		'contractors'		=> ['name' => 'contractors', 'entity' => 'Remodeling and independent businesses', 'idn' => true, 'dnssec' => true],
		'cooking'			=> ['name' => 'cooking', 'entity' => 'sharing recipes', 'idn' => true, 'dnssec' => true],
		'cool'				=> ['name' => 'cool', 'entity' => 'General interests', 'idn' => true, 'dnssec' => true],
		'country'			=> ['name' => 'country', 'entity' => 'general', 'idn' => true, 'dnssec' => true],
		'coupons'			=> ['name' => 'coupons', 'entity' => 'coupons', 'idn' => true, 'dnssec' => true],
		'credit'			=> ['name' => 'credit', 'entity' => 'Financial institutions', 'idn' => true, 'dnssec' => true],
		'creditcard'		=> ['name' => 'creditcard', 'entity' => 'Financial institutions', 'idn' => true, 'dnssec' => true],
		'cricket'			=> ['name' => 'cricket', 'entity' => 'クリケット', 'idn' => null, 'dnssec' => true],
		'cruises'			=> ['name' => 'cruises', 'entity' => 'cruise businesses and travel', 'idn' => true, 'dnssec' => true],
		'dad'				=> ['name' => 'dad', 'entity' => 'families', 'idn' => null, 'dnssec' => true],
		'dance'				=> ['name' => 'dance', 'entity' => 'Dance studios and companies', 'idn' => true, 'dnssec' => true],
		'date'				=> ['name' => 'date', 'entity' => 'online dating', 'idn' => null, 'dnssec' => true],
		'dating'			=> ['name' => 'dating', 'entity' => 'online dating', 'idn' => true, 'dnssec' => true],
		'day'				=> ['name' => 'day', 'entity' => 'general', 'idn' => null, 'dnssec' => true],
		'deals'				=> ['name' => 'deals', 'entity' => 'online shopping and couponing', 'idn' => true, 'dnssec' => true],
		'degree'			=> ['name' => 'degree', 'entity' => 'general', 'idn' => null, 'dnssec' => true],
		'delivery'			=> ['name' => 'delivery', 'entity' => 'general', 'idn' => true, 'dnssec' => true],
		'democrat'			=> ['name' => 'democrat', 'entity' => '民主党', 'idn' => true, 'dnssec' => true],
		'dental'			=> ['name' => 'dental', 'entity' => '歯科医', 'idn' => true, 'dnssec' => true],
		'dentist'			=> ['name' => 'dentist', 'entity' => '歯科医', 'idn' => null, 'dnssec' => true],
		'design'			=> ['name' => 'design', 'entity' => 'graphic art and fashion', 'idn' => true, 'dnssec' => true],
		'diamonds'			=> ['name' => 'diamonds', 'entity' => 'diamond and jewelry industry', 'idn' => true, 'dnssec' => true],
		'diet'				=> ['name' => 'diet', 'entity' => 'diet', 'idn' => true, 'dnssec' => true],
		'digital'			=> ['name' => 'digital', 'entity' => 'general', 'idn' => true, 'dnssec' => true],
		'direct'			=> ['name' => 'direct', 'entity' => 'general', 'idn' => null, 'dnssec' => true],
		'directory'			=> ['name' => 'directory', 'entity' => 'general directory', 'idn' => true, 'dnssec' => true],
		'discount'			=> ['name' => 'discount', 'entity' => 'general', 'idn' => true, 'dnssec' => true],
		'dog'				=> ['name' => 'dog', 'entity' => 'dog stores and owners', 'idn' => true, 'dnssec' => true],
		'domains'			=> ['name' => 'domains', 'entity' => 'domain registries', 'idn' => true, 'dnssec' => true],
		'download'			=> ['name' => 'download', 'entity' => 'technology', 'idn' => null, 'dnssec' => true],
		'eat'				=> ['name' => 'eat', 'entity' => 'restaurants and ', 'idn' => null, 'dnssec' => true],
		'education'			=> ['name' => 'education', 'entity' => 'educational institutes', 'idn' => true, 'dnssec' => true],
		'email'				=> ['name' => 'email', 'entity' => 'email', 'idn' => true, 'dnssec' => true],
		'energy'			=> ['name' => 'energy', 'entity' => 'energy industry and marketing', 'idn' => true, 'dnssec' => true],
		'engineer'			=> ['name' => 'engineer', 'entity' => 'engineers and engineering firms', 'idn' => true, 'dnssec' => true],
		'engineering'		=> ['name' => 'engineering', 'entity' => 'engineering firms', 'idn' => true, 'dnssec' => true],
		'equipment'			=> ['name' => 'equipment', 'entity' => 'equipment-related businesses', 'idn' => true, 'dnssec' => true],
		'esq'				=> ['name' => 'esq', 'entity' => 'lawyers, law firms, legal professionals', 'idn' => null, 'dnssec' => true],
		'estate'			=> ['name' => 'estate', 'entity' => 'real estate businesses', 'idn' => true, 'dnssec' => true],
		'events'			=> ['name' => 'events', 'entity' => 'happenings', 'idn' => true, 'dnssec' => true],
		'exchange'			=> ['name' => 'exchange', 'entity' => 'generic trade', 'idn' => true, 'dnssec' => true],
		'expert'			=> ['name' => 'expert', 'entity' => 'generic expertise', 'idn' => true, 'dnssec' => true],
		'exposed'			=> ['name' => 'exposed', 'entity' => 'general interest', 'idn' => true, 'dnssec' => true],
		'express'			=> ['name' => 'express', 'entity' => 'shipping', 'idn' => true, 'dnssec' => true],
		'fail'				=> ['name' => 'fail', 'entity' => 'general', 'idn' => true, 'dnssec' => true],
		'faith'				=> ['name' => 'faith', 'entity' => 'religion and churches', 'idn' => null, 'dnssec' => true],
		'fans'				=> ['name' => 'fans', 'entity' => 'general', 'idn' => null, 'dnssec' => true],
		'farm'				=> ['name' => 'farm', 'entity' => 'farms and agriculture', 'idn' => true, 'dnssec' => true],
		'fashion'			=> ['name' => 'fashion', 'entity' => 'clothing industry', 'idn' => true, 'dnssec' => true],
		'pid'				=> ['name' => 'pid', 'entity' => 'pid', 'idn' => null, 'dnssec' => true],
		'finance'			=> ['name' => 'finance', 'entity' => 'financial', 'idn' => true, 'dnssec' => true],
		'financial'			=> ['name' => 'financial', 'entity' => 'financial', 'idn' => true, 'dnssec' => true],
		'fish'				=> ['name' => 'fish', 'entity' => 'fishing businesses, sports, and interests', 'idn' => true, 'dnssec' => true],
		'fishing'			=> ['name' => 'fishing', 'entity' => 'fishing businesses, sports, and interests', 'idn' => true, 'dnssec' => true],
		'fit'				=> ['name' => 'fit', 'entity' => 'Fitness and exercise', 'idn' => null, 'dnssec' => true],
		'fitness'			=> ['name' => 'fitness', 'entity' => 'Fitness and exercise', 'idn' => true, 'dnssec' => true],
		'flights'			=> ['name' => 'flights', 'entity' => 'airline businesses and travel', 'idn' => true, 'dnssec' => true],
		'florist'			=> ['name' => 'florist', 'entity' => 'florists', 'idn' => true, 'dnssec' => true],
		'flowers'			=> ['name' => 'flowers', 'entity' => 'florists and gardens', 'idn' => true, 'dnssec' => true],
		'fly'				=> ['name' => 'fly', 'entity' => 'travel', 'idn' => null, 'dnssec' => true],
		'foo'				=> ['name' => 'foo', 'entity' => 'web development', 'idn' => null, 'dnssec' => true],
		'football'			=> ['name' => 'football', 'entity' => 'サッカー・アメリカンフットボール', 'idn' => true, 'dnssec' => true],
		'forsale'			=> ['name' => 'forsale', 'entity' => 'online retail', 'idn' => null, 'dnssec' => true],
		'foundation'		=> ['name' => 'foundation', 'entity' => 'charitable organizations', 'idn' => true, 'dnssec' => true],
		'fund'				=> ['name' => 'fund', 'entity' => 'financial', 'idn' => true, 'dnssec' => true],
		'furniture'			=> ['name' => 'furniture', 'entity' => 'furniture businesses', 'idn' => true, 'dnssec' => true],
		'fyi'				=> ['name' => 'fyi', 'entity' => 'for your information', 'idn' => true, 'dnssec' => true],
		'gallery'			=> ['name' => 'gallery', 'entity' => 'photo and art galleries', 'idn' => true, 'dnssec' => true],
		'garden'			=> ['name' => 'garden', 'entity' => 'gardening', 'idn' => true, 'dnssec' => true],
		'gift'				=> ['name' => 'gift', 'entity' => 'gift-giving', 'idn' => true, 'dnssec' => true],
		'gifts'				=> ['name' => 'gifts', 'entity' => 'gift-giving', 'idn' => true, 'dnssec' => true],
		'gives'				=> ['name' => 'gives', 'entity' => 'charities and gift-giving', 'idn' => null, 'dnssec' => true],
		'glass'				=> ['name' => 'glass', 'entity' => 'window sales and repairs', 'idn' => true, 'dnssec' => true],
		'global'			=> ['name' => 'global', 'entity' => 'general', 'idn' => true, 'dnssec' => true],
		'gold'				=> ['name' => 'gold', 'entity' => 'gold and luxury', 'idn' => null, 'dnssec' => true],
		'golf'				=> ['name' => 'golf', 'entity' => 'ゴルフ', 'idn' => true, 'dnssec' => true],
		'gop'				=> ['name' => 'gop', 'entity' => '共和党', 'idn' => true, 'dnssec' => true],
		'graphics'			=> ['name' => 'graphics', 'entity' => 'graphics', 'idn' => true, 'dnssec' => true],
		'green'				=> ['name' => 'green', 'entity' => 'the environmentally-focused', 'idn' => null, 'dnssec' => true],
		'gripe'				=> ['name' => 'gripe', 'entity' => 'opinion sites', 'idn' => true, 'dnssec' => true],
		'guide'				=> ['name' => 'guide', 'entity' => 'help sites', 'idn' => true, 'dnssec' => true],
		'guitars'			=> ['name' => 'guitars', 'entity' => 'Guitars', 'idn' => true, 'dnssec' => true],
		'guru'				=> ['name' => 'guru', 'entity' => 'generic expertise', 'idn' => true, 'dnssec' => true],
		'healthcare'		=> ['name' => 'healthcare', 'entity' => 'healthcare industry', 'idn' => null, 'dnssec' => true],
		'help'				=> ['name' => 'help', 'entity' => 'help sites', 'idn' => true, 'dnssec' => true],
		'here'				=> ['name' => 'here', 'entity' => 'generic geographic', 'idn' => null, 'dnssec' => true],
		'hiphop'			=> ['name' => 'hiphop', 'entity' => 'ヒップホップ文化', 'idn' => true, 'dnssec' => true],
		'hiv'				=> ['name' => 'hiv', 'entity' => 'AIDS・HIV', 'idn' => null, 'dnssec' => true],
		'hockey'			=> ['name' => 'hockey', 'entity' => 'ホッケー', 'idn' => true, 'dnssec' => true],
		'holdings'			=> ['name' => 'holdings', 'entity' => 'real estate or financial business', 'idn' => true, 'dnssec' => true],
		'holiday'			=> ['name' => 'holiday', 'entity' => 'holiday gift industry', 'idn' => true, 'dnssec' => true],
		'homes'				=> ['name' => 'homes', 'entity' => 'individuals interested in real estate and home improvement', 'idn' => null, 'dnssec' => true],
		'horse'				=> ['name' => 'horse', 'entity' => 'horse-related businesses and interest', 'idn' => true, 'dnssec' => true],
		'host'				=> ['name' => 'host', 'entity' => 'network companies', 'idn' => null, 'dnssec' => true],
		'hosting'			=> ['name' => 'hosting', 'entity' => 'hosting', 'idn' => true, 'dnssec' => true],
		'house'				=> ['name' => 'house', 'entity' => 'real estate and construction businesses', 'idn' => true, 'dnssec' => true],
		'how'				=> ['name' => 'how', 'entity' => 'how-to guides', 'idn' => null, 'dnssec' => true],
		'info'				=> ['name' => 'info', 'entity' => '情報', 'idn' => true, 'dnssec' => true],
		'ing'				=> ['name' => 'ing', 'entity' => 'Verbal suffix', 'idn' => null, 'dnssec' => true],
		'ink'				=> ['name' => 'ink', 'entity' => 'creative printing or tattooing', 'idn' => true, 'dnssec' => true],
		'institute'			=> ['name' => 'institute', 'entity' => 'institute', 'idn' => true, 'dnssec' => true],
		'insure'			=> ['name' => 'insure', 'entity' => 'Insurance companies', 'idn' => true, 'dnssec' => true],
		'international'		=> ['name' => 'international', 'entity' => 'international entities', 'idn' => true, 'dnssec' => true],
		'investments'		=> ['name' => 'investments', 'entity' => 'financial', 'idn' => true, 'dnssec' => true],
		'jewelry'			=> ['name' => 'jewelry', 'entity' => 'jewelry stores', 'idn' => true, 'dnssec' => true],
		'jobs'				=> ['name' => 'jobs', 'entity' => '雇用', 'idn' => false, 'dnssec' => true],
		'kim'				=> ['name' => 'kim', 'entity' => 'キム', 'idn' => null, 'dnssec' => true],
		'kitchen'			=> ['name' => 'kitchen', 'entity' => 'food industry and remodeling', 'idn' => true, 'dnssec' => true],
		'land'				=> ['name' => 'land', 'entity' => 'real estate', 'idn' => true, 'dnssec' => true],
		'lawyer'			=> ['name' => 'lawyer', 'entity' => 'lawyers and legal organizations', 'idn' => null, 'dnssec' => true],
		'lease'				=> ['name' => 'lease', 'entity' => 'financing', 'idn' => true, 'dnssec' => true],
		'legal'				=> ['name' => 'legal', 'entity' => 'lawyers and legal organizations', 'idn' => true, 'dnssec' => true],
		'lgbt'				=> ['name' => 'lgbt', 'entity' => 'the lesbian, gay, bisexual and transgender community', 'idn' => null, 'dnssec' => true],
		'life'				=> ['name' => 'life', 'entity' => 'general', 'idn' => true, 'dnssec' => true],
		'lighting'			=> ['name' => 'lighting', 'entity' => 'lighting', 'idn' => true, 'dnssec' => true],
		'limited'			=> ['name' => 'limited', 'entity' => 'general', 'idn' => true, 'dnssec' => true],
		'limo'				=> ['name' => 'limo', 'entity' => 'limousine businesses', 'idn' => true, 'dnssec' => true],
		'link'				=> ['name' => 'link', 'entity' => 'connecting to information', 'idn' => true, 'dnssec' => true],
		'loan'				=> ['name' => 'loan', 'entity' => 'banks and lenders', 'idn' => null, 'dnssec' => true],
		'loans'				=> ['name' => 'loans', 'entity' => 'banks and lenders', 'idn' => true, 'dnssec' => true],
		'lol'				=> ['name' => 'lol', 'entity' => 'LOL: laughing out loud', 'idn' => null, 'dnssec' => true],
		'lotto'				=> ['name' => 'lotto', 'entity' => 'lotto', 'idn' => null, 'dnssec' => true],
		'love'				=> ['name' => 'love', 'entity' => 'dating sites', 'idn' => null, 'dnssec' => true],
		'luxe'				=> ['name' => 'luxe', 'entity' => 'luxe', 'idn' => null, 'dnssec' => true],
		'luxury'			=> ['name' => 'luxury', 'entity' => 'businesses catering to the wealthy', 'idn' => true, 'dnssec' => true],
		'management'		=> ['name' => 'management', 'entity' => 'business management', 'idn' => true, 'dnssec' => true],
		'market'			=> ['name' => 'market', 'entity' => 'marketing services and retailers', 'idn' => null, 'dnssec' => true],
		'marketing'			=> ['name' => 'marketing', 'entity' => 'marketing services', 'idn' => true, 'dnssec' => true],
		'markets'			=> ['name' => 'markets', 'entity' => 'financial and stock markets', 'idn' => null, 'dnssec' => true],
		'mba'				=> ['name' => 'mba', 'entity' => '経営学修士', 'idn' => true, 'dnssec' => true],
		'media'				=> ['name' => 'media', 'entity' => 'general media interests', 'idn' => true, 'dnssec' => true],
		'meet'				=> ['name' => 'meet', 'entity' => 'social gatherings, meeting new people', 'idn' => null, 'dnssec' => true],
		'meme'				=> ['name' => 'meme', 'entity' => 'インターネットミーム', 'idn' => null, 'dnssec' => true],
		'memorial'			=> ['name' => 'memorial', 'entity' => 'memorial sites', 'idn' => true, 'dnssec' => true],
		'men'				=> ['name' => 'men', 'entity' => '男性', 'idn' => null, 'dnssec' => true],
		'menu'				=> ['name' => 'menu', 'entity' => 'レストラン', 'idn' => true, 'dnssec' => true],
		'mobi'				=> ['name' => 'mobi', 'entity' => 'モバイル端末', 'idn' => true, 'dnssec' => false],
		'moe'				=> ['name' => 'moe', 'entity' => '萌え', 'idn' => true, 'dnssec' => true],
		'money'				=> ['name' => 'money', 'entity' => '金融', 'idn' => true, 'dnssec' => true],
		'mortgage'			=> ['name' => 'mortgage', 'entity' => 'mortgage lenders', 'idn' => null, 'dnssec' => true],
		'motorcycles'		=> ['name' => 'motorcycles', 'entity' => 'motorcycles', 'idn' => null, 'dnssec' => true],
		'mov'				=> ['name' => 'mov', 'entity' => 'デジタル動画', 'idn' => null, 'dnssec' => true],
		'movie'				=> ['name' => 'movie', 'entity' => 'movies and cinemas', 'idn' => true, 'dnssec' => true],
		'museum'			=> ['name' => 'museum', 'entity' => 'museums', 'idn' => true, 'dnssec' => true],
		'name'				=> ['name' => 'name', 'entity' => 'individuals, by name', 'idn' => true, 'dnssec' => true],
		'navy'				=> ['name' => 'navy', 'entity' => 'defense contractors', 'idn' => null, 'dnssec' => true],
		'network'			=> ['name' => 'network', 'entity' => 'general', 'idn' => true, 'dnssec' => true],
		'new'				=> ['name' => 'new', 'entity' => 'general', 'idn' => null, 'dnssec' => true],
		'news'				=> ['name' => 'news', 'entity' => 'news sites', 'idn' => null, 'dnssec' => true],
		'ngo'				=> ['name' => 'ngo', 'entity' => '非政府組織', 'idn' => null, 'dnssec' => true],
		'ninja'				=> ['name' => 'ninja', 'entity' => 'general expertise', 'idn' => true, 'dnssec' => true],
		'one'				=> ['name' => 'one', 'entity' => 'generic', 'idn' => null, 'dnssec' => true],
		'ong'				=> ['name' => 'ong', 'entity' => '非政府組織', 'idn' => null, 'dnssec' => true],
		'onl'				=> ['name' => 'onl', 'entity' => 'online', 'idn' => null, 'dnssec' => true],
		'online'			=> ['name' => 'online', 'entity' => 'generic', 'idn' => null, 'dnssec' => true],
		'ooo'				=> ['name' => 'ooo', 'entity' => 'general', 'idn' => false, 'dnssec' => true],
		'organic'			=> ['name' => 'organic', 'entity' => 'organic', 'idn' => null, 'dnssec' => true],
		'partners'			=> ['name' => 'partners', 'entity' => 'businesses', 'idn' => true, 'dnssec' => true],
		'parts'				=> ['name' => 'parts', 'entity' => 'manufacturing and consumer auto', 'idn' => true, 'dnssec' => true],
		'party'				=> ['name' => 'party', 'entity' => 'nightclubs and social gatherings', 'idn' => null, 'dnssec' => true],
		'pharmacy'			=> ['name' => 'pharmacy', 'entity' => 'pharmacies', 'idn' => null, 'dnssec' => true],
		'photo'				=> ['name' => 'photo', 'entity' => 'photography and photo-sharing', 'idn' => true, 'dnssec' => true],
		'photography'		=> ['name' => 'photography', 'entity' => 'photography and photo-sharing', 'idn' => true, 'dnssec' => true],
		'photos'			=> ['name' => 'photos', 'entity' => 'photography and photo-sharing', 'idn' => true, 'dnssec' => true],
		'physio'			=> ['name' => 'physio', 'entity' => 'physical therapists', 'idn' => null, 'dnssec' => true],
		'pics'				=> ['name' => 'pics', 'entity' => 'photography and photo-sharing', 'idn' => true, 'dnssec' => true],
		'pictures'			=> ['name' => 'pictures', 'entity' => 'photography and photo-sharing', 'idn' => true, 'dnssec' => true],
		'feedback'			=> ['name' => 'feedback', 'entity' => 'feedback', 'idn' => null, 'dnssec' => true],
		'pink'				=> ['name' => 'pink', 'entity' => 'those who like the color pink', 'idn' => true, 'dnssec' => true],
		'pizza'				=> ['name' => 'pizza', 'entity' => 'pizza parlors', 'idn' => true, 'dnssec' => true],
		'place'				=> ['name' => 'place', 'entity' => 'general', 'idn' => true, 'dnssec' => true],
		'plumbing'			=> ['name' => 'plumbing', 'entity' => 'plumbing businesses', 'idn' => true, 'dnssec' => true],
		'plus'				=> ['name' => 'plus', 'entity' => 'generic', 'idn' => true, 'dnssec' => true],
		'poker'				=> ['name' => 'poker', 'entity' => 'ポーカー', 'idn' => null, 'dnssec' => true],
		'porn'				=> ['name' => 'porn', 'entity' => 'adult entertainment', 'idn' => true, 'dnssec' => true],
		'post'				=> ['name' => 'post', 'entity' => 'postal services', 'idn' => false, 'dnssec' => true],
		'press'				=> ['name' => 'press', 'entity' => 'publishing and journalism', 'idn' => null, 'dnssec' => true],
		'pro'				=> ['name' => 'pro', 'entity' => 'professions', 'idn' => false, 'dnssec' => false],
		'productions'		=> ['name' => 'productions', 'entity' => 'studio/art businesses', 'idn' => true, 'dnssec' => true],
		'prof'				=> ['name' => 'prof', 'entity' => 'Professors, teachers and learning', 'idn' => null, 'dnssec' => true],
		'properties'		=> ['name' => 'properties', 'entity' => 'real estate', 'idn' => true, 'dnssec' => true],
		'property'			=> ['name' => 'property', 'entity' => 'real estate', 'idn' => true, 'dnssec' => true],
		'qpon'				=> ['name' => 'qpon', 'entity' => 'coupons', 'idn' => null, 'dnssec' => true],
		'racing'			=> ['name' => 'racing', 'entity' => 'racing', 'idn' => null, 'dnssec' => true],
		'recipes'			=> ['name' => 'recipes', 'entity' => 'recipes and cooking', 'idn' => true, 'dnssec' => true],
		'red'				=> ['name' => 'red', 'entity' => 'those who like the color red', 'idn' => true, 'dnssec' => true],
		'rehab'				=> ['name' => 'rehab', 'entity' => 'リハビリテーションセンター and support sites', 'idn' => null, 'dnssec' => true],
		'ren'				=> ['name' => 'ren', 'entity' => '人人網ユーザー', 'idn' => null, 'dnssec' => true],
		'rent'				=> ['name' => 'rent', 'entity' => 'Real estate professionals and small businesses', 'idn' => null, 'dnssec' => true],
		'rentals'			=> ['name' => 'rentals', 'entity' => 'short-term ownership', 'idn' => true, 'dnssec' => true],
		'repair'			=> ['name' => 'repair', 'entity' => 'general repair/maintenance businesses', 'idn' => true, 'dnssec' => true],
		'report'			=> ['name' => 'report', 'entity' => 'business services', 'idn' => true, 'dnssec' => true],
		'republican'		=> ['name' => 'republican', 'entity' => '共和党 politics', 'idn' => null, 'dnssec' => true],
		'rest'				=> ['name' => 'rest', 'entity' => 'Restaurants and related industry', 'idn' => true, 'dnssec' => true],
		'review'			=> ['name' => 'review', 'entity' => 'public reviews', 'idn' => null, 'dnssec' => true],
		'reviews'			=> ['name' => 'reviews', 'entity' => 'public reviews', 'idn' => true, 'dnssec' => true],
		'rich'				=> ['name' => 'rich', 'entity' => 'businesses catering to the wealthy', 'idn' => null, 'dnssec' => true],
		'rip'				=> ['name' => 'rip', 'entity' => 'memorial sites', 'idn' => null, 'dnssec' => true],
		'rocks'				=> ['name' => 'rocks', 'entity' => 'general', 'idn' => true, 'dnssec' => true],
		'rodeo'				=> ['name' => 'rodeo', 'entity' => 'ロデオ interest', 'idn' => true, 'dnssec' => true],
		'rsvp'				=> ['name' => 'rsvp', 'entity' => 'Invitations and replies', 'idn' => null, 'dnssec' => true],
		'run'				=> ['name' => 'run', 'entity' => 'running and jogging', 'idn' => true, 'dnssec' => true],
		'sale'				=> ['name' => 'sale', 'entity' => 'retail', 'idn' => null, 'dnssec' => true],
		'school'			=> ['name' => 'school', 'entity' => 'schools', 'idn' => true, 'dnssec' => true],
		'science'			=> ['name' => 'science', 'entity' => 'science-related sites', 'idn' => null, 'dnssec' => true],
		'services'			=> ['name' => 'services', 'entity' => 'business services', 'idn' => true, 'dnssec' => true],
		'sex'				=> ['name' => 'sex', 'entity' => 'adult entertainment (pornography)', 'idn' => true, 'dnssec' => true],
		'sexy'				=> ['name' => 'sexy', 'entity' => 'adult entertainment', 'idn' => true, 'dnssec' => true],
		'shoes'				=> ['name' => 'shoes', 'entity' => 'shoes', 'idn' => true, 'dnssec' => true],
		'show'				=> ['name' => 'show', 'entity' => 'entertainment and vlogs', 'idn' => true, 'dnssec' => true],
		'singles'			=> ['name' => 'singles', 'entity' => 'online dating', 'idn' => true, 'dnssec' => true],
		'site'				=> ['name' => 'site', 'entity' => 'general', 'idn' => null, 'dnssec' => true],
		'soccer'			=> ['name' => 'soccer', 'entity' => 'サッカー', 'idn' => true, 'dnssec' => true],
		'social'			=> ['name' => 'social', 'entity' => 'general interest', 'idn' => true, 'dnssec' => true],
		'software'			=> ['name' => 'software', 'entity' => 'computer software', 'idn' => null, 'dnssec' => true],
		'solar'				=> ['name' => 'solar', 'entity' => 'solar-power', 'idn' => true, 'dnssec' => true],
		'solutions'			=> ['name' => 'solutions', 'entity' => 'business services', 'idn' => true, 'dnssec' => true],
		'space'				=> ['name' => 'space', 'entity' => 'as a creative space', 'idn' => null, 'dnssec' => true],
		'studio'			=> ['name' => 'studio', 'entity' => 'art, fitness, & entertainment', 'idn' => true, 'dnssec' => true],
		'style'				=> ['name' => 'style', 'entity' => 'fashion', 'idn' => true, 'dnssec' => true],
		'sucks'				=> ['name' => 'sucks', 'entity' => 'gripe sites', 'idn' => null, 'dnssec' => true],
		'supplies'			=> ['name' => 'supplies', 'entity' => 'manufacturing industries', 'idn' => true, 'dnssec' => true],
		'supply'			=> ['name' => 'supply', 'entity' => 'manufacturing industries', 'idn' => true, 'dnssec' => true],
		'support'			=> ['name' => 'support', 'entity' => 'help pages', 'idn' => true, 'dnssec' => true],
		'surf'				=> ['name' => 'surf', 'entity' => 'surfing', 'idn' => null, 'dnssec' => true],
		'surgery'			=> ['name' => 'surgery', 'entity' => 'healthcare industry', 'idn' => true, 'dnssec' => true],
		'systems'			=> ['name' => 'systems', 'entity' => 'technology', 'idn' => true, 'dnssec' => true],
		'tattoo'			=> ['name' => 'tattoo', 'entity' => 'tattoo aficionados', 'idn' => true, 'dnssec' => true],
		'tax'				=> ['name' => 'tax', 'entity' => 'financial', 'idn' => true, 'dnssec' => true],
		'taxi'				=> ['name' => 'taxi', 'entity' => 'taxi services', 'idn' => true, 'dnssec' => true],
		'team'				=> ['name' => 'team', 'entity' => 'team sports', 'idn' => true, 'dnssec' => true],
		'technology'		=> ['name' => 'technology', 'entity' => 'technology', 'idn' => true, 'dnssec' => true],
		'tel'				=> ['name' => 'tel', 'entity' => 'Internet communication services', 'idn' => true, 'dnssec' => false],
		'tennis'			=> ['name' => 'tennis', 'entity' => 'テニス', 'idn' => true, 'dnssec' => true],
		'theater'			=> ['name' => 'theater', 'entity' => 'theaters and cinemas', 'idn' => true, 'dnssec' => true],
		'tips'				=> ['name' => 'tips', 'entity' => 'general help topics', 'idn' => true, 'dnssec' => true],
		'tires'				=> ['name' => 'tires', 'entity' => 'tire manufacturers', 'idn' => true, 'dnssec' => true],
		'today'				=> ['name' => 'today', 'entity' => 'general', 'idn' => true, 'dnssec' => true],
		'tools'				=> ['name' => 'tools', 'entity' => 'manufacturing industries', 'idn' => true, 'dnssec' => true],
		'top'				=> ['name' => 'top', 'entity' => 'general', 'idn' => null, 'dnssec' => true],
		'tours'				=> ['name' => 'tours', 'entity' => 'tourism', 'idn' => true, 'dnssec' => true],
		'town'				=> ['name' => 'town', 'entity' => 'generic geographic', 'idn' => true, 'dnssec' => true],
		'toys'				=> ['name' => 'toys', 'entity' => 'toy businesses', 'idn' => true, 'dnssec' => true],
		'trade'				=> ['name' => 'trade', 'entity' => 'businesses', 'idn' => true, 'dnssec' => true],
		'training'			=> ['name' => 'training', 'entity' => 'training and how-tos', 'idn' => true, 'dnssec' => true],
		'travel'			=> ['name' => 'travel', 'entity' => 'travel and tourism industry related sites', 'idn' => false, 'dnssec' => false],
		'university'		=> ['name' => 'university', 'entity' => 'young adults, university life', 'idn' => true, 'dnssec' => true],
		'vacations'			=> ['name' => 'vacations', 'entity' => 'travel', 'idn' => true, 'dnssec' => true],
		'vet'				=> ['name' => 'vet', 'entity' => 'veterans and veterinarians', 'idn' => true, 'dnssec' => true],
		'video'				=> ['name' => 'video', 'entity' => 'video sharing', 'idn' => null, 'dnssec' => true],
		'villas'			=> ['name' => 'villas', 'entity' => 'real estate and/or travel businesses', 'idn' => true, 'dnssec' => true],
		'vision'			=> ['name' => 'vision', 'entity' => 'eye-care businesses', 'idn' => true, 'dnssec' => true],
		'vodka'				=> ['name' => 'vodka', 'entity' => 'ウォッカ-related businesses and interest', 'idn' => true, 'dnssec' => true],
		'vote'				=> ['name' => 'vote', 'entity' => 'democratic elections and campaign websites', 'idn' => null, 'dnssec' => true],
		'voting'			=> ['name' => 'voting', 'entity' => 'polling sites', 'idn' => true, 'dnssec' => true],
		'voyage'			=> ['name' => 'voyage', 'entity' => 'travel', 'idn' => true, 'dnssec' => true],
		'wang'				=> ['name' => 'wang', 'entity' => 'general', 'idn' => true, 'dnssec' => true],
		'watch'				=> ['name' => 'watch', 'entity' => 'Watches', 'idn' => true, 'dnssec' => true],
		'webcam'			=> ['name' => 'webcam', 'entity' => 'Web cam shows and video sharing', 'idn' => true, 'dnssec' => true],
		'website'			=> ['name' => 'website', 'entity' => 'general', 'idn' => null, 'dnssec' => true],
		'wed'				=> ['name' => 'wed', 'entity' => 'engaged couples and wedding-oriented businesses', 'idn' => false, 'dnssec' => true],
		'wedding'			=> ['name' => 'wedding', 'entity' => 'wedding-oriented businesses', 'idn' => true, 'dnssec' => true],
		'whoswho'			=> ['name' => 'whoswho', 'entity' => 'general', 'idn' => true, 'dnssec' => true],
		'wiki'				=> ['name' => 'wiki', 'entity' => 'ウィキ', 'idn' => true, 'dnssec' => true],
		'win'				=> ['name' => 'win', 'entity' => 'games, Microsoft Windows', 'idn' => null, 'dnssec' => true],
		'work'				=> ['name' => 'work', 'entity' => 'general', 'idn' => true, 'dnssec' => true],
		'works'				=> ['name' => 'works', 'entity' => 'general', 'idn' => true, 'dnssec' => true],
		'world'				=> ['name' => 'world', 'entity' => 'general', 'idn' => true, 'dnssec' => true],
		'wtf'				=> ['name' => 'wtf', 'entity' => 'general', 'idn' => true, 'dnssec' => true],
		'xxx'				=> ['name' => 'xxx', 'entity' => 'adult entertainment', 'idn' => true, 'dnssec' => true],
		'xyz'				=> ['name' => 'xyz', 'entity' => 'general', 'idn' => true, 'dnssec' => true],
		'yoga'				=> ['name' => 'yoga', 'entity' => 'ヨガ', 'idn' => true, 'dnssec' => true],
		'zone'				=> ['name' => 'zone', 'entity' => 'general', 'idn' => true, 'dnssec' => true],
		'maison'			=> ['name' => 'maison', 'entity' => 'house', 'idn' => true, 'dnssec' => true],
		'abogado'			=> ['name' => 'abogado', 'entity' => 'lawyer', 'idn' => null, 'dnssec' => true],
		'gratis'			=> ['name' => 'gratis', 'entity' => 'free', 'idn' => true, 'dnssec' => true],
		'futbol'			=> ['name' => 'futbol', 'entity' => 'サッカー', 'idn' => true, 'dnssec' => true],
		'juegos'			=> ['name' => 'juegos', 'entity' => 'games', 'idn' => true, 'dnssec' => true],
		'soy'				=> ['name' => 'soy', 'entity' => '大豆', 'idn' => true, 'dnssec' => true],
		'tienda'			=> ['name' => 'tienda', 'entity' => 'shop', 'idn' => true, 'dnssec' => true],
		'uno'				=> ['name' => 'uno', 'entity' => 'ウノ', 'idn' => true, 'dnssec' => true],
		'viajes'			=> ['name' => 'viajes', 'entity' => 'travel', 'idn' => true, 'dnssec' => true],
		'haus'				=> ['name' => 'haus', 'entity' => 'house', 'idn' => true, 'dnssec' => true],
		'immobilien'		=> ['name' => 'immobilien', 'entity' => 'real estate', 'idn' => true, 'dnssec' => true],
		'jetzt'				=> ['name' => 'jetzt', 'entity' => 'now', 'idn' => true, 'dnssec' => true],
		'kaufen'			=> ['name' => 'kaufen', 'entity' => 'buy', 'idn' => true, 'dnssec' => true],
		'reise'				=> ['name' => 'reise', 'entity' => 'travel', 'idn' => true, 'dnssec' => true],
		'reisen'			=> ['name' => 'reisen', 'entity' => 'traveling', 'idn' => true, 'dnssec' => true],
		'schule'			=> ['name' => 'schule', 'entity' => 'school', 'idn' => true, 'dnssec' => true],
		'versicherung'		=> ['name' => 'versicherung', 'entity' => 'insurance', 'idn' => true, 'dnssec' => true],
		'desi'				=> ['name' => 'desi', 'entity' => '南アジアの人々や文化を指す言葉', 'idn' => null, 'dnssec' => true],
		'shiksha'			=> ['name' => 'shiksha', 'entity' => '教育', 'idn' => null, 'dnssec' => true],
		'casa'				=> ['name' => 'casa', 'entity' => '家', 'idn' => true, 'dnssec' => true],
		'cafe'				=> ['name' => 'cafe', 'entity' => 'カフェ', 'idn' => true, 'dnssec' => true],
		'immo'				=> ['name' => 'immo', 'entity' => '不動産', 'idn' => true, 'dnssec' => true],
		'moda'				=> ['name' => 'moda', 'entity' => 'ファッション', 'idn' => true, 'dnssec' => true],
		'voto'				=> ['name' => 'voto', 'entity' => '投票', 'idn' => null, 'dnssec' => true],
		'bar'				=> ['name' => 'bar', 'entity' => 'バー', 'idn' => true, 'dnssec' => true],
		'bank'				=> ['name' => 'bank', 'entity' => '銀行', 'idn' => null, 'dnssec' => true],
		'coop'				=> ['name' => 'coop', 'entity' => '協同組合', 'idn' => false, 'dnssec' => false],
		'enterprises'		=> ['name' => 'enterprises', 'entity' => 'business associations', 'idn' => true, 'dnssec' => true],
		'industries'		=> ['name' => 'industries', 'entity' => 'industrial businesses', 'idn' => true, 'dnssec' => true],
		'institute'			=> ['name' => 'institute', 'entity' => 'Established business associations', 'idn' => true, 'dnssec' => true],
		'ltda'				=> ['name' => 'ltda', 'entity' => '南アメリカの企業', 'idn' => null, 'dnssec' => true],
		'pub'				=> ['name' => 'pub', 'entity' => 'パブ', 'idn' => true, 'dnssec' => true],
		'realtor'			=> ['name' => 'realtor', 'entity' => '不動産仲買業者', 'idn' => null, 'dnssec' => true],
		'reit'				=> ['name' => 'reit', 'entity' => 'REIT', 'idn' => null, 'dnssec' => true],
		'rest'				=> ['name' => 'rest', 'entity' => 'レストラン', 'idn' => true, 'dnssec' => true],
		'restaurant'		=> ['name' => 'restaurant', 'entity' => 'レストラン', 'idn' => true, 'dnssec' => true],
		'sarl'				=> ['name' => 'sarl', 'entity' => '有限会社', 'idn' => true, 'dnssec' => true],
		'ventures'			=> ['name' => 'ventures', 'entity' => 'funding for start-ups', 'idn' => true, 'dnssec' => true],
	];
}
